@@ -107,9 +107,9 @@ sub AceSearchTable {
     start_form(-action=>url(-absolute=>1,-path_info=>1).'#results',%attributes),
     a({-name=>'search'},''),
     table({-border=>0,-width=>'100%'},
-	  TR(th({-class=>'searchtitle'},$title),
-	  TR({-valign=>'CENTER'},
-	     td({-class=>'searchbody'},@body)))),
+	  TR(th({-class=>'searchtitle'},$title)),
+	  TR({-valign=>'MIDDLE'},
+	     td({-class=>'searchbody'},@body))),
     end_form;
 }
 
@@ -153,7 +153,7 @@ sub AceResultsTable {
   $title ||= 'Search Results';
 
   print 
-    a({-name=>'results'}),
+    a({-name=>'results'},''),
     start_table({-border=>0,-cellspacing=>2,-cellpadding=>2,-width=>'100%',-align=>'CENTER',-class=>'resultsbody'}),
     TR(th({-class=>'resultstitle'},$title));
   unless (@$objects) {
